var videoElement = document.getElementsByClassName('video-stream')[0];

var speedModifier = 1.0;
var disableRateChangeEventListener = false; //Prevents event listener from triggering itself

//Using Chrome sync storage.
//The speed difference will be there on
//all of their devices, as long as they're signed in
//and using Chrome.
chrome.storage.sync.get(["lastRateChange"], function(items) {
    if(items.lastRateChange == null) {
        var now = new Date();
        now.setHours(24, 0, 0, 0);
        var rateChangeObj = {
            "timestamp": +now,
            "value": 1.00 //Gives a day of buffer time
        };
        chrome.storage.sync.set({"lastRateChange": rateChangeObj});
    }
    else {
        speedModifier = items.lastRateChange.value;
        //Speed loses 0.01, even if multiple days have passed.
        //If the user goes on vacation or doesn't visit YouTube for a few days,
        //they won't lose a few percent speed, which could be noticeable.
        if(speedModifier > 0.7 && new Date() > new Date(items.lastRateChange.timestamp)) { //It's the next day at minimum
            speedModifier -= 0.01;
            var now = new Date();
            now.setHours(24, 0, 0, 0);
            var rateChangeObj = {
                "timestamp": +now,
                "value": speedModifier
            };
            chrome.storage.sync.set({"lastRateChange": rateChangeObj});
        }
        disableRateChangeEventListener = true;
        videoElement.playbackRate *= speedModifier;
    }
});

videoElement.addEventListener('ratechange', function() { //Ensures speed controls still work
    if(!disableRateChangeEventListener) {
        disableRateChangeEventListener = true;
        var hasSound = videoElement.playbackRate >= 0.5;
        videoElement.playbackRate *= speedModifier;
        //Sound playback doesn't work if the video is playing slower than half speed.
        //This could raise some alarms if sound stops even when the user selects 0.5x speed.
        //So, if sound should be enabled, this adds a hard cap of 0.5x.
        //If the user selects 0.25, there's no sound anyway, so there's no reason to
        //enable this cap.
        if(hasSound && videoElement.playbackRate < 0.5) videoElement.playbackRate = 0.5;
    } else {
        disableRateChangeEventListener = false;
    }
});
